@@ -99,7 +99,7 @@ def to_local_average_cents(salience, center=None):
 
     if not hasattr(to_local_average_cents, 'cents_mapping'):
         # the bin number-to-cents mapping
-        to_local_average_cents.mapping = (
+        to_local_average_cents.cents_mapping = (
                 np.linspace(0, 7180, 360) + 1997.3794084376191)
 
     if salience.ndim == 1:
@@ -109,7 +109,7 @@ def to_local_average_cents(salience, center=None):
         end = min(len(salience), center + 5)
         salience = salience[start:end]
         product_sum = np.sum(
-            salience * to_local_average_cents.mapping[start:end])
+            salience * to_local_average_cents.cents_mapping[start:end])
         weight_sum = np.sum(salience)
         return product_sum / weight_sum
     if salience.ndim == 2:
@@ -141,7 +141,7 @@ def to_viterbi_cents(salience):
                 ((1 - self_emission) / 360))
 
     # fix the model parameters because we are not optimizing the model
-    model = hmm.MultinomialHMM(360, starting, transition)
+    model = hmm.CategoricalHMM(360, starting, transition)
     model.startprob_, model.transmat_, model.emissionprob_ = \
         starting, transition, emission
 
@@ -206,7 +206,7 @@ def get_activation(audio, sr, model_capacity='full', center=True, step_size=10,
 
     # normalize each frame -- this is expected by the model
     frames -= np.mean(frames, axis=1)[:, np.newaxis]
-    frames /= np.std(frames, axis=1)[:, np.newaxis]
+    frames /= np.clip(np.std(frames, axis=1)[:, np.newaxis], 1e-8, None)
 
     # run prediction and convert the frequency bin weights to Hz
     return model.predict(frames, verbose=verbose)
